pub struct EvalRunOptions {
pub paths: Vec<PathBuf>,
pub filter: Option<String>,
pub max_concurrency: NonZeroUsize,
}Expand description
Request to discover and run a collection of declarative eval files.
Fields
paths: Vec<PathBuf>Eval files or directories to discover eval files under. Empty means ./evals.
filter: Option<String>When set, run only the eval with this name.
max_concurrency: NonZeroUsizeTrait Implementations
Sourceimpl Clone for EvalRunOptions
impl Clone for EvalRunOptions
Sourcefn clone(&self) -> EvalRunOptions
fn clone(&self) -> EvalRunOptions
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for EvalRunOptions
impl RefUnwindSafe for EvalRunOptions
impl Send for EvalRunOptions
impl Sync for EvalRunOptions
impl Unpin for EvalRunOptions
impl UnsafeUnpin for EvalRunOptions
impl UnwindSafe for EvalRunOptions