pub struct EvalSpecLoadOptions {
pub paths: Vec<PathBuf>,
pub filter: Option<String>,
}Expand description
Options for discovering and loading resolved eval specs.
Fields
paths: Vec<PathBuf>Eval files or directories to discover eval files under. Empty means ./evals.
filter: Option<String>When set, load only the eval with this name.