pub struct EvalToolCall {
pub name: String,
pub arguments: Option<Value>,
pub raw_arguments: String,
}Fields
name: Stringarguments: Option<Value>raw_arguments: StringTrait Implementations
Sourceimpl Clone for EvalToolCall
impl Clone for EvalToolCall
Sourcefn clone(&self) -> EvalToolCall
fn clone(&self) -> EvalToolCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EvalToolCall
impl Debug for EvalToolCall
Sourceimpl JsonSchema for EvalToolCall
impl JsonSchema for EvalToolCall
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for EvalToolCall
impl RefUnwindSafe for EvalToolCall
impl Send for EvalToolCall
impl Sync for EvalToolCall
impl Unpin for EvalToolCall
impl UnsafeUnpin for EvalToolCall
impl UnwindSafe for EvalToolCall