pub struct JudgeCriterionResponse {
pub id: String,
pub score: f64,
pub reason: String,
}Fields
id: Stringscore: f64reason: StringTrait Implementations
Sourceimpl Debug for JudgeCriterionResponse
impl Debug for JudgeCriterionResponse
Sourceimpl<'de> Deserialize<'de> for JudgeCriterionResponse
impl<'de> Deserialize<'de> for JudgeCriterionResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for JudgeCriterionResponse
impl JsonSchema for JudgeCriterionResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for JudgeCriterionResponse
impl RefUnwindSafe for JudgeCriterionResponse
impl Send for JudgeCriterionResponse
impl Sync for JudgeCriterionResponse
impl Unpin for JudgeCriterionResponse
impl UnsafeUnpin for JudgeCriterionResponse
impl UnwindSafe for JudgeCriterionResponse