pub struct JudgeCriterionSummary {
pub id: String,
pub description: String,
pub blocking: bool,
pub weight: f64,
pub threshold: f64,
pub score: f64,
pub passed: bool,
pub reason: String,
}Fields
id: Stringdescription: Stringblocking: boolweight: f64threshold: f64score: f64passed: boolreason: StringTrait Implementations
Sourceimpl Clone for JudgeCriterionSummary
impl Clone for JudgeCriterionSummary
Sourcefn clone(&self) -> JudgeCriterionSummary
fn clone(&self) -> JudgeCriterionSummary
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for JudgeCriterionSummary
impl Debug for JudgeCriterionSummary
Sourceimpl JsonSchema for JudgeCriterionSummary
impl JsonSchema for JudgeCriterionSummary
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for JudgeCriterionSummary
impl RefUnwindSafe for JudgeCriterionSummary
impl Send for JudgeCriterionSummary
impl Sync for JudgeCriterionSummary
impl Unpin for JudgeCriterionSummary
impl UnsafeUnpin for JudgeCriterionSummary
impl UnwindSafe for JudgeCriterionSummary