ResolvedEvalSpec

Struct ResolvedEvalSpec 

pub struct ResolvedEvalSpec {
    pub name: String,
    pub base_dir: PathBuf,
    /* private fields */
}
An EvalSpec resolved against its base directory.

Fields

name: Stringbase_dir: PathBuf

Implementations

Source

impl ResolvedEvalSpec

pub fn load(options: EvalSpecLoadOptions) -> Result<Vec<Self>, EvalFileError>

Discover, read, and parse eval files using the provided options. Directory discovery is recursive and includes files ending in .eval.json. Explicit file paths are always treated as eval files, regardless of filename.

pub fn load_file(path: impl AsRef<Path>) -> Result<Self, EvalFileError>

Read and parse an eval file, resolving it against its base directory (the eval file’s parent).

pub fn resolve( eval: EvalSpec, base_dir: impl Into<PathBuf>, ) -> Result<Self, EvalFileError>

Resolve a parsed eval file against base_dir, resolving the Docker image and reading referenced judge files.