pub struct RetainedWorkspaceInfo {
pub root_path: PathBuf,
pub path: PathBuf,
}Fields
root_path: PathBufpath: PathBufTrait Implementations
Sourceimpl Clone for RetainedWorkspaceInfo
impl Clone for RetainedWorkspaceInfo
Sourcefn clone(&self) -> RetainedWorkspaceInfo
fn clone(&self) -> RetainedWorkspaceInfo
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RetainedWorkspaceInfo
impl Debug for RetainedWorkspaceInfo
Sourceimpl JsonSchema for RetainedWorkspaceInfo
impl JsonSchema for RetainedWorkspaceInfo
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RetainedWorkspaceInfo
impl RefUnwindSafe for RetainedWorkspaceInfo
impl Send for RetainedWorkspaceInfo
impl Sync for RetainedWorkspaceInfo
impl Unpin for RetainedWorkspaceInfo
impl UnsafeUnpin for RetainedWorkspaceInfo
impl UnwindSafe for RetainedWorkspaceInfo