ContextUsage

Struct ContextUsage 

pub struct ContextUsage {
    pub usage_ratio: Option<f64>,
    pub context_limit: Option<u32>,
    pub input_tokens: u32,
    pub output_tokens: u32,
    pub cache_read_tokens: Option<u32>,
    pub cache_creation_tokens: Option<u32>,
    pub reasoning_tokens: Option<u32>,
    pub total_input_tokens: u64,
    pub total_output_tokens: u64,
    pub total_cache_read_tokens: u64,
    pub total_cache_creation_tokens: u64,
    pub total_reasoning_tokens: u64,
}
Context/token usage reported after an LLM call.

Fields

usage_ratio: Option<f64>

Current usage ratio (0.0 - 1.0), if context window is known.

context_limit: Option<u32>

Maximum context limit, if known.

input_tokens: u32

Input tokens on the most recent API call (the current context size).

output_tokens: u32

Output tokens on the most recent API call.

cache_read_tokens: Option<u32>

Prompt tokens served from cache on the most recent API call.

cache_creation_tokens: Option<u32>

Prompt tokens written to cache on the most recent API call.

reasoning_tokens: Option<u32>

Reasoning tokens spent on the most recent API call.

total_input_tokens: u64

Cumulative input tokens since the agent started.

total_output_tokens: u64

Cumulative output tokens since the agent started.

total_cache_read_tokens: u64

Cumulative cache-read tokens since the agent started.

total_cache_creation_tokens: u64

Cumulative cache-creation tokens since the agent started.

total_reasoning_tokens: u64

Cumulative reasoning tokens since the agent started.

Implementations

Source

impl ContextUsage

pub fn total_tokens(&self) -> u64

Sum of cumulative input + output tokens.